# {{NAME}}

This project has been scaffolded by Meshroom.
It defines a cybersecurity mesh architecture (CSMA) following the OXA project's guidelines

You may clone this mesh and use the `meshroom` CLI to extend it, deploy it on your cyber ecosystem and contribute new product integrations